Documentation
¶
Index ¶
Constants ¶
const (
NotFound = Error("levelup: not found")
)
Variables ¶
var ( DefaultRangeLimit = 9999999 DefaultRangeEnd = []byte{0xff, 0xff, 0xff, 0xff, 0xff} )
var BatchDel = Del
var BatchPut = Put
Functions ¶
This section is empty.
Types ¶
type RangeOpts ¶
type RangeOpts struct {
Start []byte // included, default []byte{}
End []byte // not included, default []byte{0xff, 0xff, 0xff, 0xff, 0xff}
Reverse bool // default false
Limit int // default 9999999
}
func (*RangeOpts) FillDefaults ¶
func (ro *RangeOpts) FillDefaults()
type ReadIterator ¶
type ReadIterator interface {
Valid() bool // returns false when we have reached the end of the rows we asked for.
Next() // go to the next row.
Key() []byte // the key in the current row.
Value() []byte // the value in the current row.
Error() error // if some error has happened this have it.
Release() // it may be necessary to call this after using, or defer it.
}
Click to show internal directories.
Click to hide internal directories.